@@ -10,9 +10,8 @@ describe 'keystone' do
       it { is_expected.to contain_class('keystone::policy') }
 
       it { is_expected.to contain_package('keystone').with(
-        :ensure => 'present',
-        :name   => platform_params[:package_name],
-        :tag    => ['openstack', 'keystone-package'],
+        'ensure' => 'present',
+        'tag'    => ['openstack', 'keystone-package'],
       ) }
 
       it { is_expected.to contain_class('keystone::client').with(
@@ -42,6 +41,11 @@ describe 'keystone' do
         is_expected.to contain_keystone_config('revoke/driver').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('policy/driver').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('ssl/enable').with_value(false)
+        is_expected.to contain_keystone_config('ssl/certfile').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('ssl/keyfile').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('ssl/ca_certs').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('ssl/ca_key').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('ssl/cert_subject').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('token/revoke_by_id').with_value(true)
 
         is_expected.to contain_oslo__middleware('keystone_config').with(
@@ -133,6 +137,11 @@ describe 'keystone' do
         is_expected.to contain_keystone_config('revoke/driver').with_value('sql')
         is_expected.to contain_keystone_config('policy/driver').with_value('sql')
         is_expected.to contain_keystone_config('ssl/enable').with_value(false)
+        is_expected.to contain_keystone_config('ssl/certfile').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('ssl/keyfile').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('ssl/ca_certs').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('ssl/ca_key').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_keystone_config('ssl/cert_subject').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_keystone_config('token/revoke_by_id').with_value(true)
 
         is_expected.to contain_oslo__middleware('keystone_config').with(
@@ -165,7 +174,7 @@ describe 'keystone' do
       end
 
       it { is_expected.to contain_exec('restart_keystone').with(
-        'command' => "systemctl restart #{platform_params[:httpd_service_name]}",
+        'command' => "service #{platform_params[:httpd_service_name]} restart",
       ) }
     end
 
@@ -373,13 +382,11 @@ describe 'keystone' do
       it { is_expected.to contain_file('/etc/keystone/credential-keys/0').with(
         'content'   => 't-WdduhORSqoyAykuqWAQSYjg2rSRuJYySgI2xh48CI=',
         'owner'     => 'keystone',
-        :show_diff  => false,
         'subscribe' => 'Anchor[keystone::install::end]',
       )}
       it { is_expected.to contain_file('/etc/keystone/credential-keys/1').with(
         'content'   => 'GLlnyygEVJP4-H2OMwClXn3sdSQUZsM5F194139Unv8=',
         'owner'     => 'keystone',
-        :show_diff  => false,
         'subscribe' => 'Anchor[keystone::install::end]',
       )}
     end
@@ -527,7 +534,7 @@ describe 'keystone' do
       end
 
       it { is_expected.to contain_exec('restart_keystone').with(
-        'command' => "systemctl restart #{platform_params[:service_name]}",
+        'command' => "service #{platform_params[:service_name]} restart",
       ) }
       it { is_expected.to contain_anchor('default_domain_created') }
     end
@@ -623,7 +630,7 @@ describe 'keystone' do
       let (:facts) do
         facts.merge!(OSDefaults.get_facts({
           :concat_basedir => '/var/lib/puppet/concat',
-          :fqdn           => 'some.host.tld',
+          :fqdn           => 'some.host.tld'
         }))
       end
 
@@ -634,7 +641,7 @@ describe 'keystone' do
             :service_name       => 'keystone',
             :httpd_service_name => 'apache2' }
         when 'RedHat'
-          { :package_name       => 'openstack-keystone',
+          { :package_name       => 'opnestack-keystone',
             :service_name       => 'openstack-keystone',
             :httpd_service_name => 'httpd' }
         end
